# Hookshot Python Library

The Hookshot Python library provides convenient access to the Hookshot API from
applications written in the Python language. It includes a pre-defined set of
classes for API resources that initialize themselves dynamically from API
responses which makes it compatible with a wide range of versions of the Hookshot
API.

## Documentation

See the [Python API docs](https://docs.hookshothq.com).

## Installation

You don't need this source code unless you want to modify the package. If you just
want to use the package, just run:

```sh
pip install --upgrade hookshothq
```

Install from source with:

```sh
python setup.py install
```
